<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>DesktopSwitch</name>
    <message>
        <location filename="../desktopswitch.cpp" line="96"/>
        <source>Switch to desktop %1</source>
        <translation>Přepnout na plochu %1</translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="171"/>
        <location filename="../desktopswitch.cpp" line="182"/>
        <source>Desktop %1</source>
        <translation>Plocha %1</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchConfiguration</name>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="14"/>
        <source>DesktopSwitch Settings</source>
        <translation>Nastavení přepínání ploch</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="46"/>
        <source>Number of rows:</source>
        <translation>Počet řádků:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="39"/>
        <source>Desktop labels:</source>
        <translation>Popisky ploch:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="54"/>
        <source>Numbers</source>
        <translation>Čísla</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="59"/>
        <source>Names</source>
        <translation>Názvy</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="64"/>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="72"/>
        <source>If checked, widget will be just an indicator</source>
        <translation>Pokud zaškrtnuto, ovládací prvek bude pouze ukazatelem</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="75"/>
        <source>Show only active desktop</source>
        <translation>Zobrazovat pouze pracovní plochu, na které se nacházíte</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="85"/>
        <source>Desktop names</source>
        <translation>Názvy ploch</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.cpp" line="78"/>
        <source>Desktop %1:</source>
        <translation>Plocha %1:</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchUnsupported</name>
    <message>
        <location filename="../desktopswitch.cpp" line="343"/>
        <source>n/a</source>
        <translation>není dostupné</translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="345"/>
        <source>DesktopSwitch is unsupported on current platform: %1</source>
        <translation>Služba DesktopSwitch není na současné platformě podporována: %1</translation>
    </message>
</context>
</TS>
